import{p as e,H as t,b as r}from"./p-1ae4c1ec.js";export{s as setNonce}from"./p-1ae4c1ec.js";import{g as o}from"./p-e1255160.js";var n=e=>{const s=e.cloneNode;e.cloneNode=function(e){if("TEMPLATE"===this.nodeName)return s.call(this,e);const t=s.call(this,!1),r=this.childNodes;if(e)for(let e=0;e<r.length;e++)2!==r[e].nodeType&&t.appendChild(r[e].cloneNode(!0));return t}};(()=>{n(t.prototype);const s=import.meta.url,r={};return""!==s&&(r.resourcesUrl=new URL(".",s).href),e(r)})().then((async e=>(await o(),r([["p-aab8c000",[[0,"django-hstore-widget",{json:[513],field_name:[513],cols:[514],rows:[514],delete_svg_src:[1],add_svg_src:[1],edit_svg_src:[1],mounted:[32],error:[32],textarea_value:[32],output_render_type:[32],__json:[32]},null,{json:["jsonWatcher"],__json:["__jsonWatcher"]}]]]],e))));